@@ -923,7 +923,7 @@ if_sendnetlink(struct dhcpcd_ctx *ctx, int protocol, struct nlmsghdr *hdr,
 		int on = 1;
 
 		if (setsockopt(s, SOL_NETLINK, NETLINK_GET_STRICT_CHK,
-		    &on, sizeof(on)) == -1)
+		    &on, sizeof(on)) == -1 && errno != ENOPROTOOPT)
 			logerr("%s: NETLINK_GET_STRICT_CHK", __func__);
 	}
 #endif
@@ -1569,16 +1569,13 @@ bpf_read(struct interface *ifp, int s, void *data, size_t len,
 	*flags |= BPF_EOF; /* We only ever read one packet. */
 	*flags &= ~BPF_PARTIALCSUM;
 	if (bytes) {
-		ssize_t fl = (ssize_t)bpf_frame_header_len(ifp);
-
 		if (bpf_frame_bcast(ifp, state->buffer) == 0)
 			*flags |= BPF_BCAST;
 		else
 			*flags &= ~BPF_BCAST;
-		bytes -= fl;
 		if ((size_t)bytes > len)
 			bytes = (ssize_t)len;
-		memcpy(data, state->buffer + fl, (size_t)bytes);
+		memcpy(data, state->buffer, (size_t)bytes);
 #ifdef PACKET_AUXDATA
 		for (cmsg = CMSG_FIRSTHDR(&msg);
 		     cmsg;
@@ -1876,11 +1873,10 @@ if_setup_inet6(const struct interface *ifp)
 	snprintf(path, sizeof(path), "%s/%s/accept_ra", p_conf, ifp->name);
 	ra = check_proc_int(path);
 	if (ra == -1) {
-		logfunc_t *logfunc = errno == ENOENT? logdebug : logwarn;
-
 		/* The sysctl probably doesn't exist, but this isn't an
 		 * error as such so just log it and continue */
-		logfunc("%s", path);
+		if (errno != ENOENT)
+			logerr("%s: %s", __func__, path);
 	} else if (ra != 0) {
 		if (if_writepathuint(path, 0) == -1)
 			logerr("%s: %s", __func__, path);
